@@ -49,7 +49,7 @@ class CalibrationClient(CalibrationApi,
 
         # Generate unique name if it doesn't exist
         cc_name_01 = '{0}_{1}'.format(detector_type_name, calibration_name)
-        cc_name_uk = '{0}_{1}'.format(cc_name_01[:40], condition_name[:19])
+        cc_name_uk = '{0}_{1}'.format(cc_name_01[:40], condition_name)
         cc_name = Util.get_opt_hash_val(cc_h, 'name', cc_name_uk)
 
         #
