@@ -4,6 +4,8 @@ from .calibration import Calibration
 from .calibration_constant import CalibrationConstant
 from .calibration_constant_version import CalibrationConstantVersion
 from .condition import Condition
-from .device_type import DeviceType
+from .detector import Detector
+from .detector_type import DetectorType
 from .parameter import Parameter
-from .physical_device import PhysicalDevice
+from .physical_detector_unit import PhysicalDetectorUnit
+from .report import Report
