@@ -85,7 +85,7 @@ class ParameterApiTest(ApiBase, unittest.TestCase):
         unique_name_upd = generate_unique_name('ParameterApiUpd')
         parameter_upd = {
             PARAMETER: {
-                'name': unique_name_upd,
+                'name': expect['name'],
                 # 'unit_id': '-1',
                 'flg_available': False,
                 'flg_logarithmic': True,
@@ -105,7 +105,6 @@ class ParameterApiTest(ApiBase, unittest.TestCase):
         self.fields_validation(receive, expect_upd)
         assert res.status_code == HTTPStatus.OK
 
-        assert expect['name'] != expect_upd['name']
         assert expect['flg_available'] != expect_upd['flg_available']
         assert expect['flg_logarithmic'] != expect_upd['flg_logarithmic']
         assert expect['def_lower_deviation_value'] \
